@@ -363,7 +363,7 @@ class HardwareViewSet(viewsets.ModelViewSet):
             return HttpResponse(render(request, 'hardwares.html'))
 
 
-from data.forms.forms import DataTransformerForm, DataTransform
+from data.forms.forms import DataTransformerForm, DataTransform, DataTransformRoot
 from data.models.models import DataTransformer
 
 
@@ -390,16 +390,16 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         accessory_form = AccessoryForm(instance=accessory)
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
-        datatransformerset = inlineformset_factory(DataTransformer, DataTransformer,formset=DataTransformerForm,
-                                                   fk_name='parent', form=DataTransform)
+        # datatransformerset = inlineformset_factory(DataTransformer, DataTransformer,formset=DataTransformerForm,
+        #                                            fk_name='parent', form=DataTransform,extra=0)
 
         if accessory.has_data_transformer:
             data_transformer = accessory.datatransformer
-            formset = datatransformerset(initial=[DataTransform(instance=data_transformer)])
+            formset = DataTransformRoot(instance=data_transformer)
         else:
-            data_transformer = DataTransformer.objects.create(accessory=accessory)
-            data_transformer.save()
-            formset = datatransformerset(initial=[DataTransform(instance=data_transformer)])
+            data_transformer_root = DataTransformer.objects.create(accessory=accessory)
+            data_transformer_root.save()
+            formset = DataTransformRoot(instance=data_transformer_root)
 
         if request.accepted_renderer.format == 'html':
             return Response(
